c              test primary sampling routines
#include  "BlockData/cblkGene.h"

      implicit none
#include  "Zmanagerp.h"
#include  "Ztrack.h"
#include  "Ztrackv.h"
#include  "Zprimary.h"
      
      record /ptcl/ p
      record /track/incident
      record /coord/ angle

      real*8 kin
      integer label, icon, i


      call creadParam(5)
      call cbeginRun
      call cprintPrim(ErrorOut)
      write(ErrorOut, 
     *   '("#seq. No.|   Orig Erg | Code # | Total E(GeV)")')
      do i = 1, DestEventNo(1)
         icon = 1
         do while (icon .ne. 0)
            call csampPrimary(incident.p)
            call csPrimAng(angle)
            call cmkInc(incident, angle)
            if(CutOffFile .ne. ' ') then
               call cifCutOff(icon)
            else
              icon =0
            endif
         enddo
         call cqPrimE(kin)
         call cqPrimLabel(label)
         p = incident.p
         write(*, *) label, sngl(kin),
     *      p.code,  sngl(p.fm.p(4)), sngl(log10(kin)), sngl(1/kin)
      enddo
      end
      subroutine chookTrace
      end
      subroutine chookCeren
      end
      subroutine chookCerenS
      end
      subroutine chookCerenE
      end
      subroutine chookBgRun
      end
